tests.test_radix module — justbases 0.07 documentation

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- tests »
- tests package »

# tests.test_radix module

Test for rational conversions.

class `tests.test_radix.` `RadixTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Tests for radix.

  `testCarryOnRepeatingPart`()

    Carry from non_repeating_part to integer_part and then out.

  `testEquality`()

    Test == operator.

  `testExceptions`()

    Test exceptions.

  `testInBase`()

    Test that roundtrip is identity modulo number of 0s in non repeating part.

  `testInEquality`()

    Test != operator.

  `testOperatorExceptions`()

    Test that comparsion operators yield exceptions.

  `testOptions`()

    Skip validation and canonicalization.

  `testRepeatingRepeatPart`()

    Repeat part is made up of repeating parts.

  `testRepr`()

    Make sure that result is evalable.

  `testStr`()

    Check basic properties of __str__.

class `tests.test_radix.` `RoundingTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Tests for rounding Radixes.

  `testAsInt`()

    Test equivalence with two paths.

  `testExceptions`()

    Test exception.

  `testRoundFraction`()

    Test that rounding yields the correct number of digits.

    Test that rounded values are in a good range.

  `testRoundRelation`()

    Test that all results have the correct relation.

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- tests »
- tests package »